@@ -1,10 +1,11 @@
 import typer
 from requests import HTTPError
+from rich.console import Console
 
 from odd_cli.client import Client
-from odd_cli.error import CreateTokenError
 
 app = typer.Typer(short_help="Manipulate OpenDataDiscovery platform's tokens")
+err_console = Console(stderr=True)
 
 
 @app.command()
@@ -20,7 +21,7 @@ def create(
         return token
     except HTTPError as e:
         message = e.response.json().get("message")
-        raise CreateTokenError(name, message or "unknown")
+        err_console.print(message or "Could not create token.{e}", style="red")
 
 
 if __name__ == "__main__":
